function [WorstBuffRank,RunTime,LowerRankOfBuffRank]=WorstBuffRankFun(mInput,mOutput,iDMUo)
%inputs
%mInput: matrix of inputs, x_jm, row: DMU, column: input
%mOutput:matrix of outputs, x_jn, row: DMU, column: output
%jDMUo: a number, the DMU to be evaluated

%output
%WorstRank: number, the Worst rank for DMUo
%RunTime: time in seconds, running time for computing DMUo's Worst ranking
%RankOfBuffRank: the upper rank of DMUo in J measures E_j(nu*,mu*)

problem_statement_WorstBuffRank=...
             ['minimize', char(10),...
              '  bPOE_g(0, matrix_H)', char(10),...
              'Box: >= 0',char(10),...
              'Solver: van, init_point=0.1'];

[J,nInput]=size(mInput);
[J1,nOutput]=size(mOutput);
vInputDMUo=mInput(iDMUo,:);
vOutputDMUo=mOutput(iDMUo,:);

colnames={};
for i=1:nInput; colnames{i}=sprintf('nu_%g',i); end
for i=1:nOutput; colnames{nInput+i}=sprintf('mu_%g',i); end
mDMU=[mInput,-mOutput];

%H=mDMU-[vInputDMUo,-vOutputDMUo].*ones(J,1);
for i=1:J; H(i,:)=mDMU(i,:)-[vInputDMUo,-vOutputDMUo]; end

iargstruc_BuffRank(1) = matrix_pack('matrix_H',H,colnames);

[solution, outargstruc] = mpsg_solver(problem_statement_WorstBuffRank, iargstruc_BuffRank);
fval= tbpsg_solution(solution, outargstruc,'objective');  
status=tbpsg_solution(solution, outargstruc,'solution_status');
vTime=tbpsg_solution(solution, outargstruc,'time');
RunTime=vTime(3);
WorstBuffRank=J+1-J*fval;

vSoluWorstBRank=get_optimalpoint(solution, iargstruc_BuffRank, outargstruc);
for iInput=1:nInput
    vOptNu(iInput,1)=vSoluWorstBRank{iInput,2};
end
for iOutput=1:nOutput
    vOptMu(iOutput,1)=vSoluWorstBRank{iOutput+nInput,2};
end
for jDMU=1:J
    vEffMeasure(jDMU,1)=mOutput(jDMU,:)*vOptMu-mInput(jDMU,:)*vOptNu;
end
LowerRankOfBuffRank=J-sum(vEffMeasure<vEffMeasure(iDMUo));